FileBackedValue

Struct FileBackedValue 

pub struct FileBackedValue { /* private fields */ }

Implementations

Source

impl FileBackedValue

pub fn new(filename: &str) -> Self

Create a file-backed value in the user’s data directory.

Example
  • Linux: /home/alice/.local/share
  • MacOS: /Users/Alice/Library/Application Support
  • Windows: C:\Users\Alice\AppData\Roaming
pub fn new_at(filename: &str, parent: &Path) -> Self

Create a file-backed value in the specified directory.

pub fn set_dirty_time(&mut self, dirty_time: Duration)

Set the duration after which the file is considered dirty and needs to be recomputed.

pub fn path(&self) -> &PathBuf

Path to the backing file.

pub fn clear(&mut self) -> Result<()>

Clear the currently stored value and remove the backing file.

pub fn get<T>(&mut self) -> FileBackedValueResult<Option<T>>

Get the current value, which might be None if the backing file does not yet exist.

pub fn get_or_insert<T>(&mut self, default: T) -> FileBackedValueResult<T>

Get the current value, or insert default if the backing file does not exist or is dirty.

pub fn get_or_insert_with<F, T>( &mut self, default: F, ) -> FileBackedValueResult<T>
where F: FnOnce() -> T, T: DeserializeOwned + Serialize,

Get the current value, or insert default() if the backing file does not exist or is dirty.

pub fn insert<T>(&mut self, value: &T)
where T: Serialize,

Inserts value into the option and writes it to the backing file.